==> sane-0.51.tar.gz: sane-0.51/sanei/sanei_codec_bin.c <==
/* sane - Scanner Access Now Easy.
   Copyright (C) 1997 David Mosberger-Tang
   This file is part of the SANE package.

   SANE is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   SANE is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
   or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
   License for more details.

   You should have received a copy of the GNU General Public License
   along with sane; see the file COPYING.  If not, write to the Free
   Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
#include <errno.h>
#include <stdlib.h>
#include <string.h>

#include <sane.h>
#include <sanei_wire.h>
#include <sanei_codec_bin.h>

static void
bin_w_byte (Wire *w, void *v)
{
  SANE_Byte *b = v;

  sanei_w_space (w, 1);
  switch (w->direction)
    {
    case WIRE_ENCODE:
      *w->buffer.curr++ = *b;
      break;

    case WIRE_DECODE:
      *b = *w->buffer.curr++;
      break;

    case WIRE_FREE:
	break;
    }
}

static void
bin_w_string (Wire *w, void *v)
{
  SANE_Word len;
  SANE_String *s = v;

  if (w->direction == WIRE_ENCODE)
    {
      len = 0;
      if (*s)
	len = strlen (*s) + 1;
    }
  sanei_w_array (w, &len, v, w->codec.w_byte, 1);
  if (!len && w->direction == WIRE_DECODE)
    *s = 0;
}

static void
bin_w_word (Wire *w, void *v)
{
  SANE_Word val, *word = v;

  sanei_w_space (w, 4);
  switch (w->direction)
    {
    case WIRE_ENCODE:
      val = *word;
      /* store in bigendian byte-order: */
      w->buffer.curr[0] = (val >> 24) & 0xff;
      w->buffer.curr[1] = (val >> 16) & 0xff;
      w->buffer.curr[2] = (val >>  8) & 0xff;
      w->buffer.curr[3] = (val >>  0) & 0xff;
      w->buffer.curr += 4;
      break;

    case WIRE_DECODE:
      val = (  ((w->buffer.curr[0] & 0xff) << 24)
	     | ((w->buffer.curr[1] & 0xff) << 16)
	     | ((w->buffer.curr[2] & 0xff) <<  8)
	     | ((w->buffer.curr[3] & 0xff) <<  0));
      *word = val;
      w->buffer.curr += 4;
      break;

    case WIRE_FREE:
      break;
    }
}

void
sanei_codec_bin_init (Wire *w)
{
  w->codec.w_byte = bin_w_byte;
  w->codec.w_char = bin_w_byte;
  w->codec.w_word = bin_w_word;
  w->codec.w_string = bin_w_string;
}

==> sane-0.55.tar.gz: sane-0.55/sanei/sanei_codec_bin.c <==
/* sane - Scanner Access Now Easy.
   Copyright (C) 1997 David Mosberger-Tang
   This file is part of the SANE package.

   SANE is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   SANE is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
   or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
   License for more details.

   You should have received a copy of the GNU General Public License
   along with sane; see the file COPYING.  If not, write to the Free
   Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
#include <errno.h>
#include <stdlib.h>
#include <string.h>

#include <sane/sane.h>
#include <sane/sanei_wire.h>
#include <sane/sanei_codec_bin.h>

static void
bin_w_byte (Wire *w, void *v)
{
  SANE_Byte *b = v;

  sanei_w_space (w, 1);
  switch (w->direction)
    {
    case WIRE_ENCODE:
      *w->buffer.curr++ = *b;
      break;

    case WIRE_DECODE:
      *b = *w->buffer.curr++;
      break;

    case WIRE_FREE:
	break;
    }
}

static void
bin_w_string (Wire *w, void *v)
{
  SANE_Word len;
  SANE_String *s = v;

  if (w->direction == WIRE_ENCODE)
    {
      len = 0;
      if (*s)
	len = strlen (*s) + 1;
    }
  sanei_w_array (w, &len, v, w->codec.w_byte, 1);
  if (!len && w->direction == WIRE_DECODE)
    *s = 0;
}

static void
bin_w_word (Wire *w, void *v)
{
  SANE_Word val, *word = v;

  sanei_w_space (w, 4);
  switch (w->direction)
    {
    case WIRE_ENCODE:
      val = *word;
      /* store in bigendian byte-order: */
      w->buffer.curr[0] = (val >> 24) & 0xff;
      w->buffer.curr[1] = (val >> 16) & 0xff;
      w->buffer.curr[2] = (val >>  8) & 0xff;
      w->buffer.curr[3] = (val >>  0) & 0xff;
      w->buffer.curr += 4;
      break;

    case WIRE_DECODE:
      val = (  ((w->buffer.curr[0] & 0xff) << 24)
	     | ((w->buffer.curr[1] & 0xff) << 16)
	     | ((w->buffer.curr[2] & 0xff) <<  8)
	     | ((w->buffer.curr[3] & 0xff) <<  0));
      *word = val;
      w->buffer.curr += 4;
      break;

    case WIRE_FREE:
      break;
    }
}

void
sanei_codec_bin_init (Wire *w)
{
  w->codec.w_byte = bin_w_byte;
  w->codec.w_char = bin_w_byte;
  w->codec.w_word = bin_w_word;
  w->codec.w_string = bin_w_string;
}
